===========
evaporation
===========


.. image:: https://img.shields.io/pypi/v/evaporation.svg
        :target: https://pypi.python.org/pypi/evaporation

.. image:: https://img.shields.io/travis/openmeteo/evaporation.svg
        :target: https://travis-ci.org/openmeteo/evaporation

.. image:: https://codecov.io/github/openmeteo/evaporation/coverage.svg
        :target: https://codecov.io/gh/openmeteo/evaporation
        :alt: Coverage

.. image:: https://pyup.io/repos/github/openmeteo/evaporation/shield.svg
         :target: https://pyup.io/repos/github/openmeteo/evaporation/
         :alt: Updates

Calculation of evaporation and transpiration

* Free software: GNU General Public License v3
* Documentation: https://evaporation.readthedocs.io.
